#!/bin/sh
# this script will install the dotfiles from the target git repository, and back up any conflicting files
# credit for the basic outline of this script goes to https://www.atlassian.com/git/tutorials/dotfiles

DOTFILES_REPO_DIR="$HOME/git/dotfiles"
DOTFILES_REPO_URL="https://git.blakenorth.net/dotfiles"
DOTFILES_BACKUP_DIR="$HOME/.dotfiles-backup_$(date +'%Y-%m-%d_%H:%m:%S')"

set -e

printf "\n  Installing dotfiles from $DOTFILES_REPO_URL\n\n"

# check for the git command and exit if it doesn't exist
if ! command -v git > /dev/null;then
   echo 'git is not installed or could not be found in PATH, please install git to proceed'
   exit 1
fi

git clone --bare "$DOTFILES_REPO_URL" "$DOTFILES_REPO_DIR" || echo "Resuming installation"

dot() {
   git --git-dir="$DOTFILES_REPO_DIR" --work-tree="$HOME" "$@"
}

# remove the '> /dev/null' part if things don't seem to work right
if ! dot checkout > /dev/null 2>&1; then
   echo "Backing up pre-existing dotfiles."
   mkdir -p "$DOTFILES_BACKUP_DIR"

   # get the list of files that need to be backed up
   while read -r LINE; do
      LINE_DIR="$(dirname "$LINE")" # No file
      mkdir -p "$DOTFILES_BACKUP_DIR/$LINE_DIR"
      mv "$HOME/$LINE" "$DOTFILES_BACKUP_DIR/$LINE_DIR"
   done <<< "$(dot checkout 2>&1 | grep -Po '\t\K.*$')"
fi

dot checkout
dot config status.showUntrackedFiles no

printf "\nInstallation complete!\n"
